==> patch-2.5.5.3_6_3.zip: post-commands/2.5.5.3_6_3-postrelease.sh <==
PARABLU_COMPONENT_SCRIPT_PATH=../../config/parablu_component_config.sh
PARABLU_CONFIG_SCRIPT_PATH=../../config/parablu_config.sh

source $PARABLU_COMPONENT_SCRIPT_PATH
source $PARABLU_CONFIG_SCRIPT_PATH

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] ||  [ "$SERVER_TYPE" == "3 1" ]; then

echo 'use parablu001
db.MONGO_PROPERTIES.find({}).forEach(function(e){print("P_USERNAME=" +e.HostedNginixSetup)})' > checkngi.js
sudo mongo localhost:$DBPORT -u "neil" -p "parablu" --authenticationDatabase "admin" < checkngi.js > checkngi

PY_UNAME=$(grep "P_USERNAME" checkngi | sed -e 's/P_USERNAME=//')
        if [ "$PY_UNAME" == "true" ]; then

                sed -i "s|app.constant('BASE_FOLDER', '/portal');|app.constant('BASE_FOLDER', 'https://GHOSTURL/GHOSTNAME/portal');|" /var/www/portal/app/templates/default/js/angular/app.js
                sed -i "s|GHOSTNAME|$NG_IP|"  /var/www/portal/app/templates/default/js/angular/app.js
                sed -i "s|GHOSTURL|$NG_RL|"  /var/www/portal/app/templates/default/js/angular/app.js
		sed -i "s|HOST|$NG_IP|"  indexnew.html
		cp -rp  indexnew.html index.html
                cp -rp index.html /var/www/
        fi
fi


if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] || [ "$SERVER_TYPE" == "3 1" ]; then

        chown -R tomcat:parablu Users.xlsx
        cp -rp Users.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkCreateUsers.xlsx
        cp -rp bulkCreateUsers.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu  bulkBlockUnblockDeleteAssets.xlsx
        cp -rp bulkBlockUnblockDeleteAssets.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkBlockUnblockDeleteUsers.xlsx
        cp -rp bulkBlockUnblockDeleteUsers.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkBlockUnblockDeleteUsersAdvanced.xlsx
        cp -rp bulkBlockUnblockDeleteUsersAdvanced.xlsx /parablu/bkpOverview/


fi

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "1 2" ] || [ "$SERVER_TYPE" == "3 1" ]; then

cp -rp  htaccessnginix .htaccess
chown -R  www-data:www-data .htaccess
cp -rp .htaccess /var/www/portal/

fi

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] ||  [ "$SERVER_TYPE" == "3 1" ]; then
                dbport=$(grep port: /etc/mongod.conf)
                MONGODB_PORT=$(echo $dbport | sed -e 's/port://' | sed 's/"//g' | tr -d ' ')
                sudo mongo localhost:$MONGODB_PORT -u "neil" -p "parablu" --authenticationDatabase "admin" < chunkfile.js >> ../2.5.5.3_6_3_mongo.log

fi

==> patch-2.5.5.3_6_7.zip: post-commands/2.5.5.3_6_7-postrelease.sh <==
PARABLU_COMPONENT_SCRIPT_PATH=../../config/parablu_component_config.sh
PARABLU_CONFIG_SCRIPT_PATH=../../config/parablu_config.sh

source $PARABLU_COMPONENT_SCRIPT_PATH
source $PARABLU_CONFIG_SCRIPT_PATH

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] ||  [ "$SERVER_TYPE" == "3 1" ]; then

echo 'use parablu001
db.MONGO_PROPERTIES.find({}).forEach(function(e){print("P_USERNAME=" +e.HostedNginixSetup)})' > checkngi.js
sudo mongo localhost:$DBPORT -u "neil" -p "parablu" --authenticationDatabase "admin" < checkngi.js > checkngi

PY_UNAME=$(grep "P_USERNAME" checkngi | sed -e 's/P_USERNAME=//')
        if [ "$PY_UNAME" == "true" ]; then

                sed -i "s|app.constant('BASE_FOLDER', '/portal');|app.constant('BASE_FOLDER', 'https://GHOSTURL/GHOSTNAME/portal');|" /var/www/portal/app/templates/default/js/angular/app.js
                sed -i "s|GHOSTNAME|$NG_IP|"  /var/www/portal/app/templates/default/js/angular/app.js
                sed -i "s|GHOSTURL|$NG_RL|"  /var/www/portal/app/templates/default/js/angular/app.js
		sed -i "s|HOST|$NG_IP|"  indexnew.html
		cp -rp  indexnew.html index.html
                cp -rp index.html /var/www/
        fi
fi


if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] || [ "$SERVER_TYPE" == "3 1" ]; then

        chown -R tomcat:parablu Users.xlsx
        cp -rp Users.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkCreateUsers.xlsx
        cp -rp bulkCreateUsers.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu  bulkBlockUnblockDeleteAssets.xlsx
        cp -rp bulkBlockUnblockDeleteAssets.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkBlockUnblockDeleteUsers.xlsx
        cp -rp bulkBlockUnblockDeleteUsers.xlsx /parablu/bkpOverview/

        chown -R tomcat:parablu bulkBlockUnblockDeleteUsersAdvanced.xlsx
        cp -rp bulkBlockUnblockDeleteUsersAdvanced.xlsx /parablu/bkpOverview/


fi

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "1 2" ] || [ "$SERVER_TYPE" == "3 1" ]; then

cp -rp  htaccessnginix .htaccess
chown -R  www-data:www-data .htaccess
cp -rp .htaccess /var/www/portal/

fi

##legacyjobchange

if [ "$SERVER_TYPE" == "0" ] || [ "$SERVER_TYPE" == "3" ] ||  [ "$SERVER_TYPE" == "3 1" ]; then
                dbport=$(grep port: /etc/mongod.conf)
                MONGODB_PORT=$(echo $dbport | sed -e 's/port://' | sed 's/"//g' | tr -d ' ')
                sudo mongo localhost:$MONGODB_PORT -u "neil" -p "parablu" --authenticationDatabase "admin" < legacyjob.js >> ../2.5.5.3_6_7_mongo.log

fi


cp -r LegacyBluKryptJob.war /var/lib/tomcat-job1/webapps

service tomcat-job1 stop
sleep 2s
cp -r /var/lib/tomcat-job1/webapps/BluKryptJob/WEB-INF/classes/privacygateway.properties  /var/lib/tomcat-job1/webapps/LegacyBluKryptJob/WEB-INF/classes/
rm -rf /var/lib/tomcat-job1/webapps/LegacyBluKryptJob.war

service tomcat-job1 start
sleep 2s
service tomcat-job1 restart
